export const colorLegend = (selection, props) => {
  const {colorScale, 
         circleRadius, 
         spacing, 
         textOffset,
         backgroundRectWidth,
         onClick,
         selectedColorValue
        } = props;
  
  const backgroundRect = selection.selectAll('rect')
    .data([null]);
  
  const n = colorScale.domain().length;
  backgroundRect.enter().append('rect')
    .merge(backgroundRect)
      .attr('height',spacing * (n+1) +circleRadius)
      .attr('width',backgroundRectWidth)
      .attr('fill', 'white')
      .attr('x',-circleRadius*2)
      .attr('y',-circleRadius*2)
      .attr('rx',circleRadius*2)
      .attr('opacity',0.8);
  
  const legendTitle = selection.selectAll('text')
    .data([null]);
  legendTitle.enter().append('text')
    .merge(legendTitle)
      .attr('x',0)
      .attr('y',0)
      .text('Rating')
      .attr('font-family','sans-serif')
  
  const groups = selection.selectAll('.tick')
    .data(colorScale.domain());
  
  const groupsEnter = groups
    .enter().append('g')
    .attr('class', 'tick')
  ; 
  
  groupsEnter
    .merge(groups)
      .attr('transform', (d, i) =>
        `translate(0,${(i+1) * spacing})`)
      .attr('opacity',d => 
        (!selectedColorValue) || (d === selectedColorValue)
            ? 1
            : 0.3
       );

  
  groups.exit().remove();
  
  groupsEnter.append('circle')
    .merge(groups.select('circle'))
      .attr('r',circleRadius)
      .attr('fill', colorScale)
    .on('click', d=> onClick(
      d=== selectedColorValue
        ? null
        : d
    ));

  groupsEnter.append('text')
    .merge(groups.select('text'))
      .text(d => d)
      .attr('x', textOffset)
      .attr('dy', '0.32em');

} 
 