import {
  select,
  scaleOrdinal,
  schemeReds,
  range
} from 'd3';

import { loadAndProcessData } from './loadAndProcessData';
import { choroplethMap } from './choroplethMap';
import { colorLegend } from './colorLegend';

const svg = select('svg');
const choroplethMapG = svg.append('g');
const colorLegendG = svg.append('g')
    .attr('transform',`translate(25,320)`);

const colorScale = scaleOrdinal(); 
const colorValue = d => d.properties.Review;

let selectedColorValue;
let features;
 
const onClick = d => {
  selectedColorValue = d;
  render();
}

loadAndProcessData().then(countries => {
  features = countries.features;
  render();
  
});

const domain = ['NA','1','2','3','4','5']


const render = () => {
  colorScale
    .domain(domain)
    .domain(colorScale.domain())
    .range(schemeReds[colorScale.domain().length]);
  
  colorLegendG.call(colorLegend,{
    colorScale,
    circleRadius: 10,
    spacing: 23,
    textOffset: 23,
    backgroundRectWidth:80,
    onClick,
    selectedColorValue
  });
  

  choroplethMapG.call(choroplethMap,{
    features,
    colorScale,
    colorValue,
    selectedColorValue
  })
  
  
}
